==> hinemos_src-4.0.4.tar.gz: HinemosManager/src_snmptrap/com/clustercontrol/snmptrap/factory/DeleteOidMaster.java <==
/*

Copyright (C) 2008 NTT DATA Corporation

This program is free software; you can redistribute it and/or
Modify it under the terms of the GNU General Public License
as published by the Free Software Foundation, version 2.

This program is distributed in the hope that it will be
useful, but WITHOUT ANY WARRANTY; without even the implied
warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
PURPOSE.  See the GNU General Public License for more details.

 */

package com.clustercontrol.snmptrap.factory;

import java.util.List;

import javax.ejb.CreateException;
import javax.ejb.EJBException;
import javax.ejb.FinderException;
import javax.ejb.RemoveException;
import javax.naming.NamingException;
import javax.transaction.HeuristicMixedException;
import javax.transaction.HeuristicRollbackException;
import javax.transaction.InvalidTransactionException;
import javax.transaction.NotSupportedException;
import javax.transaction.RollbackException;
import javax.transaction.SystemException;
import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

import com.clustercontrol.fault.InvalidSetting;
import com.clustercontrol.fault.MonitorNotFound;
import com.clustercontrol.monitor.ejb.session.MonitorSettingControllerLocal;
import com.clustercontrol.monitor.ejb.session.MonitorSettingControllerUtil;
import com.clustercontrol.monitor.run.bean.MonitorInfo;
import com.clustercontrol.monitor.run.bean.MonitorTrapValueInfo;
import com.clustercontrol.snmptrap.bean.SnmpTrapMasterInfo;
import com.clustercontrol.snmptrap.ejb.entity.SnmpTrapMasterLocal;
import com.clustercontrol.snmptrap.ejb.entity.SnmpTrapMasterPK;
import com.clustercontrol.snmptrap.ejb.entity.SnmpTrapMasterUtil;
import com.clustercontrol.util.apllog.AplLogger;

/**
 * OIDマスター情報を削除するクラス<BR>
 *
 * @version 2.4.0
 * @since 2.4.0
 * @author Yosuke
 */
public class DeleteOidMaster {

	protected static Log m_log = LogFactory.getLog( DeleteOidMaster.class );


	protected SnmpTrapMasterPK m_OidPk;

	/**
	 * OID情報を削除します。
	 * 
	 * @param OIDData　削除するOIDマスター
	 * @param user　　　削除実行ユーザ
	 * @return
	 * @throws CreateException
	 * @throws NotSupportedException
	 * @throws RollbackException
	 * @throws HeuristicMixedException
	 * @throws HeuristicRollbackException
	 * @throws SystemException
	 * @throws InvalidTransactionException
	 * @throws NamingException
	 * @throws MonitorNotFound
	 * @throws InvalidSetting 
	 */
	public boolean delete(SnmpTrapMasterInfo oidData) throws CreateException, NotSupportedException, RollbackException, HeuristicMixedException, HeuristicRollbackException, SystemException, InvalidTransactionException, NamingException, MonitorNotFound, InvalidSetting {

		this.m_OidPk = new SnmpTrapMasterPK(oidData.getMib(),
				oidData.getTrapOid(),
				oidData.getGenericId(),
				oidData.getSpecificId());

		boolean result = false;
		
		// SNMPTRAP監視でトラップを個別設定している情報を取得
		MonitorSettingControllerLocal monSettingCtrl = null;
		List<MonitorInfo> monitorTrapList = null;
		try {
			monSettingCtrl = MonitorSettingControllerUtil.getLocalHome().create();
			monitorTrapList = monSettingCtrl.getTrapList();
		} catch (Exception e) {
			m_log.error(e, e);
		}
		
		List<MonitorTrapValueInfo> trapInfoList; 
		
		if (monitorTrapList != null) {
			for (MonitorInfo monitor : monitorTrapList) {
				trapInfoList = monitor.getTrapValueInfo();
				
				if (trapInfoList != null && trapInfoList.size() > 0) {
					SnmpTrapMasterPK oidPk;
					for (MonitorTrapValueInfo trapInfo : trapInfoList) {
						oidPk = new SnmpTrapMasterPK(
								trapInfo.getMib(), 
								trapInfo.getTrapOid(), 
								trapInfo.getGenericId(), 
								trapInfo.getSpecificId());
						
						if(this.m_OidPk.equals(oidPk)) {
							String message = "this oid is used. : " + "MIB = " + trapInfo.getMib() + ", OID = " + trapInfo.getTrapOid(); 
							m_log.info("delete() : " + message); 
							throw new InvalidSetting(message);
						}
					}
				}
			}
		}
		
		// 監視情報を登録
		result = deleteOIDMaster();

		return result;
	}

	/**
	 * OIDマスターの削除を行う。
	 * @param user　削除実行ユーザ
	 * @return
	 * @throws NamingException
	 * @throws MonitorNotFound
	 */
	public boolean deleteOIDMaster() throws NamingException, MonitorNotFound {
		boolean result = false;

		try
		{

			// 監視情報を検索

			SnmpTrapMasterLocal OIDMaster =  SnmpTrapMasterUtil.getLocalHome()
			.findByPrimaryKey(m_OidPk);

			OIDMaster.remove();

			result = true;

		} catch (NamingException e) {
			outputLog(e, "deleteOIDMaster()");
			throw e;
		} catch (EJBException e) {
			outputLog(e, "deleteOIDMaster()");
			throw e;
		} catch (RemoveException e) {
			outputLog(e, "deleteOIDMaster()");
			try {
				throw e;
			} catch (RemoveException e1) {
				outputLog(e1, "deleteOIDMaster()");
			}
		} catch (FinderException e) {
			outputLog(e, "deleteOIDMaster()");
			throw new MonitorNotFound(e.getMessage(), e);
		}
		return result;
	}

	/**
	 * アプリケーションログにログを出力
	 * 
	 * @param e 例外
	 */
	private void outputLog(Exception e, String method){
		AplLogger apllog = new AplLogger("TRAP", "trap");
		String[] args = {m_OidPk.getMib(),
				m_OidPk.getTrapOid(),
				Integer.toString(m_OidPk.getGenericId()),
				Integer.toString(m_OidPk.getSpecificId())};
		apllog.put("SYS", "001", args);
		m_log.debug(method + ":" + e.getMessage());
	}
}

==> hinemos_src-4.1.1.tar.gz: HinemosManager/src_snmptrap/com/clustercontrol/snmptrap/factory/DeleteOidMaster.java <==
/*

Copyright (C) 2008 NTT DATA Corporation

This program is free software; you can redistribute it and/or
Modify it under the terms of the GNU General Public License
as published by the Free Software Foundation, version 2.

This program is distributed in the hope that it will be
useful, but WITHOUT ANY WARRANTY; without even the implied
warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
PURPOSE.  See the GNU General Public License for more details.

 */

package com.clustercontrol.snmptrap.factory;

import javax.persistence.EntityManager;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

import com.clustercontrol.commons.util.JpaTransactionManager;
import com.clustercontrol.fault.MonitorNotFound;
import com.clustercontrol.snmptrap.bean.SnmpTrapMasterInfo;
import com.clustercontrol.snmptrap.entity.SnmpTrapMasterPK;
import com.clustercontrol.snmptrap.model.SnmpTrapMstEntity;
import com.clustercontrol.snmptrap.util.QueryUtil;

/**
 * OIDマスター情報を削除するクラス<BR>
 *
 * @version 2.4.0
 * @since 2.4.0
 * @author Yosuke
 */
public class DeleteOidMaster {

	private static Log m_log = LogFactory.getLog( DeleteOidMaster.class );


	private SnmpTrapMasterPK m_OidPk;

	/**
	 * OID情報を削除します。
	 * 
	 * @param OIDData　削除するOIDマスター
	 * @param user　　　削除実行ユーザ
	 * @return
	 * @throws MonitorNotFound
	 */
	public boolean delete(SnmpTrapMasterInfo oidData) throws MonitorNotFound {

		this.m_OidPk = new SnmpTrapMasterPK(oidData.getMib(),
				oidData.getTrapOid(),
				oidData.getGenericId(),
				oidData.getSpecificId());

		boolean result = false;

		// 監視情報を登録
		result = deleteOIDMaster();

		return result;
	}

	/**
	 * OIDマスターの削除を行う。
	 * @param user　削除実行ユーザ
	 * @return
	 * @throws MonitorNotFound
	 */
	public boolean deleteOIDMaster() throws MonitorNotFound {
		boolean result = false;
		EntityManager em = new JpaTransactionManager().getEntityManager();

		// 監視情報を検索
		SnmpTrapMstEntity entity = QueryUtil.getSnmpTrapMstPK(
				m_OidPk.getMib(),
				m_OidPk.getTrapOid(),
				m_OidPk.getGenericId(),
				m_OidPk.getSpecificId());
		entity.unchain();	// 削除前処理
		em.remove(entity);

		result = true;
		return result;
	}
}
